Slayer Framework... It came to SLAY!
====================================

Requirements:
^^^^^^^^^^^^^

- Python 3.x (Python >= 3.6 recommended)

For web automation, make sure you have a webdriver downloaded in your system, and it's added to your PATH.


Running the Framework
=====================
.. code-block:: bash

    pip install slayer

Once installed:

.. code-block:: python

   from slayer import run_framework
   run_framework()